
float4x4 tW: WORLD;
float4x4 tV: VIEW;
float4x4 tP: PROJECTION;
float4x4 tWVP: WORLDVIEWPROJECTION;

texture Src1 <string uiname="Source1";>;
sampler Src1Samp = sampler_state
{
    Texture   = (Src1);
    MipFilter = LINEAR;
    MinFilter = LINEAR;
    MagFilter = LINEAR;
};

texture Src2 <string uiname="Source2";>;
sampler Src2Samp = sampler_state
{
    Texture   = (Src2);
    MipFilter = LINEAR;
    MinFilter = LINEAR;
    MagFilter = LINEAR;
};



float4x4 tTex: TEXTUREMATRIX <string uiname="Source1 Transform";>;
float4x4 tTex2: TEXTUREMATRIX <string uiname="Source2 Transform";>;

struct vs2ps
{
    float4 Pos  : POSITION;
    float2 TexCd : TEXCOORD0;
    float2 Tex2Cd : TEXCOORD1;
    float2 MaskCd : TEXCOORD2;
};

// --------------------------------------------------------------------------------------------------
// VERTEXSHADERS
// --------------------------------------------------------------------------------------------------
vs2ps VS(
    float4 PosO  : POSITION,
    float4 TexCd : TEXCOORD0,
    float2 Tex2Cd : TEXCOORD1,
    float2 MaskCd : TEXCOORD2)
{
    vs2ps Out = (vs2ps)0;
    Out.Pos = mul(PosO, tWVP);
    Out.TexCd = mul(TexCd, tTex);
    Out.Tex2Cd = mul(TexCd, tTex2);
    return Out;
}

// --------------------------------------------------------------------------------------------------
// PIXELSHADERS:
// --------------------------------------------------------------------------------------------------
float blend;
float alpha;

float4 psFade(vs2ps In): COLOR
{
    float4 sc1 = tex2D(Src1Samp, In.TexCd);
    float4 sc2 = tex2D(Src2Samp, In.Tex2Cd);
    float4 outColor = sc1 * (1-blend) + sc2 * (blend);
    outColor.a = outColor.a * alpha;
    return outColor;
}


// --------------------------------------------------------------------------------------------------
// TECHNIQUES:
// --------------------------------------------------------------------------------------------------

technique Fade
{
    pass P0
    {
        VertexShader = compile vs_1_0 VS();
        PixelShader  = compile ps_1_0 psFade();
    }
}


technique TFixedFunction
{
    pass P0
    {
        //transforms
        WorldTransform[0]   = (tW);
        ViewTransform       = (tV);
        ProjectionTransform = (tP);

        //texturing
        Sampler[0] = (Src1Samp);
        TextureTransform[0] = (tTex);
        TexCoordIndex[0] = 0;
        TextureTransformFlags[0] = COUNT2;
        //Wrap0 = U;  // useful when mesh is round like a sphere
        
        Lighting       = FALSE;

        //shaders
        VertexShader = NULL;
        PixelShader  = NULL;
    }
}
